==> hx-oem-0.1.11.tgz: package/js/packing/index.js <==
var http = require('../libs/httpUtils.js');
var tools = require('../libs/oem_tools.js');
var files = require('../libs/files.js');
var cmd = require('../libs/cmd.js');
var config = require('../../config/index');

var succApks = [];
var packingdataInfo = [];

var androidPath = config.oemParms[config.type].androidPath;

function packingApk(packings) {
  packingdataInfo = [];
  succApks = [];
  _reqOemInfo((json) => {
    var select_data = tools.select(json.data, packings);
    files.save(androidPath + config.oemFile, select_data)
      .then((json) => _buildApk(json.data))
      .catch((e) => {
        console.log(e)
      });
  });
}

function oemList() {
  _reqOemInfo(json => {

    var arr = json.data,
      len = arr.length,
      num = 5,
      _ = v => {
        for (var i = v.length; i < 20; i++) {
          v += ' '
        }
        v += '|';
        return v;
      };
    for (var i = 0; i < len; i += num) {
      var s = '|';
      for (var j = 0; j < num && i + j < len; j++) {
        s += _(arr[i + j].oem);
      }
      console.log(s);
    }
  });
}

function _reqOemInfo(succ, err) {
  http.get(config.oemParms[config.type].oemUrl).then((json) => {
    succ && succ(json);
  }).catch((e) => {
    err ? err(e) : console.log(e)
  });
}

function _buildApk(arr) {
  var map = arr[0];
  if (map) {
    http.downloadFile(androidPath + config.androidImagPath + '/ic_oem.png', map.logo144)
      .then(() => {
        var cmdstr = 'cd ' + androidPath +
          {'w': ' && gradlew assemble', 'os': ' && ./gradlew assemble'}[config.system]
          + tools.toUpperFirst(map.oem) + 'Release';
        console.log('cmd:' + cmdstr);
        console.log('start packing ' + map.oem);
        cmd(cmdstr).then(() => {
          console.log('finish packing ' + map.oem);
          succApks.push(map.oem);
          let apInfo = tools.getApkPaths([map.oem]);
          packingdataInfo.push({
            apkEName: map.oem,
            file: apInfo.dirname + apInfo.apks[0],
            api_token: map.firToken
          });
          arr.splice(0, 1);
          _buildApk(arr);
        });
      })
      .catch((e) => {
        console.log(e)
      });
  } else {
    console.log('finish packing');
    var paths = tools.getApkPaths(succApks);
    console.log(succApks);
    console.log(paths);
    files.save(androidPath + '/oem/packing.list', {data: packingdataInfo});
    // http.uploadApks(paths);
  }
}


module.exports = {packingApk, oemList};

==> hx-oem-0.1.12.tgz: package/js/packing/index.js <==
var http = require('../libs/httpUtils.js');
var tools = require('../libs/oem_tools.js');
var files = require('../libs/files.js');
var cmd = require('../libs/cmd.js');
var config = require('../../config/index');

var succApks = [];
var errApks = [];
var packingdataInfo = [];

var androidPath = config.oemParms[config.type].androidPath;

function packingApk(packings) {
  packingdataInfo = [];
  succApks = [];
  errApks = [];
  _reqOemInfo((json) => {
    var select_data = tools.select(json.data, packings);
    files.save(androidPath + config.oemFile, select_data)
      .then((json) => _buildApk(json.data))
      .catch((e) => {
        console.log(e)
      });
  });
}

function oemList() {
  _reqOemInfo(json => {

    var arr = json.data,
      len = arr.length,
      num = 5,
      _ = v => {
        for (var i = v.length; i < 20; i++) {
          v += ' '
        }
        v += '|';
        return v;
      };
    for (var i = 0; i < len; i += num) {
      var s = '|';
      for (var j = 0; j < num && i + j < len; j++) {
        s += _(arr[i + j].oem);
      }
      console.log(s);
    }
  });
}

function _reqOemInfo(succ, err) {
  http.get(config.oemParms[config.type].oemUrl).then((json) => {
    succ && succ(json);
  }).catch((e) => {
    err ? err(e) : console.log(e)
  });
}

function _buildApk(arr) {
  var map = arr[0];
  if (map) {
    http.downImagesPromise(androidPath + config.androidImagPath + '/ic_oem.png', map)
      .then(() => {
        var cmdstr = 'cd ' + androidPath +
          {'w': ' && gradlew assemble', 'os': ' && ./gradlew assemble'}[config.system]
          + tools.toUpperFirst(map.oem) + 'Release';
        console.log('cmd:' + cmdstr);
        console.log('start packing ' + map.oem);
        return cmd(cmdstr).then(() => {
          console.log('finish packing ' + map.oem);
          succApks.push(map.oem);
          let apInfo = tools.getApkPaths([map.oem]);
          packingdataInfo.push({
            apkEName: map.oem,
            file: apInfo.dirname + apInfo.apks[0],
            api_token: map.firToken
          });
          arr.splice(0, 1);
          _buildApk(arr);
        });
      })
      .catch((e) => {
        console.log(e)
        errApks.push({name: map.oem, error: e});
        arr.splice(0, 1);
        _buildApk(arr);
      });
  } else {
    var paths = tools.getApkPaths(succApks);
    console.log("----------- 错误包信息 -----------");
    console.log(errApks);
    console.log("----------- 成功包信息 -----------");
    console.log(succApks);
    console.log("----------- paths -----------");
    console.log(paths);
    files.save(androidPath + '/oem/packing.list', {data: packingdataInfo});
    console.log("----------- 打包结束 -----------");
    // http.uploadApks(paths);
  }
}


module.exports = {packingApk, oemList};
